@@ -1,9 +1,10 @@
-__version__ = '0.6.1'
+__version__ = '0.6.2'
 __author__ = 'Neil Freeman'
 __license__ = 'GPL'
-__all__ = ['api', 'confighelper', 'creation', 'helpers', 'tools']
+__all__ = ['api', 'archive', 'confighelper', 'creation', 'helpers', 'tools']
 
 from . import api
+from . import archive
 from . import helpers
 from . import confighelper
 from .creation import add_default_args, defaults, setup_args
